Package: BioPlex
Title: R-side access to BioPlex protein-protein interaction data
Version: 1.15.0
Authors@R: 
    c(person("Ludwig", "Geistlinger",
             role = c("aut", "cre"),
             email = "ludwig_geistlinger@hms.harvard.edu"),
      person("Robert", "Gentleman",
             role = "aut"))
Description: The BioPlex package implements access to the BioPlex protein-protein
             interaction networks and related resources from within R. 
             Besides protein-protein interaction networks for HEK293 and HCT116 cells,
             this includes access to CORUM protein complex data, and transcriptome
             and proteome data for the two cell lines.  
             Functionality focuses on importing the various data resources and
             storing them in dedicated Bioconductor data structures, as a 
             foundation for integrative downstream analysis of the data. 
URL: https://github.com/ccb-hms/BioPlex
BugReports: https://github.com/ccb-hms/BioPlex/issues
Encoding: UTF-8
License: Artistic-2.0
VignetteBuilder: knitr
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.2.3
Depends: R (>= 4.1.0), SummarizedExperiment
Imports: BiocFileCache, GenomicRanges, GenomeInfoDb, GEOquery, graph,
        methods, utils
Suggests: AnnotationDbi, AnnotationHub, BiocStyle, DEXSeq,
        ExperimentHub, GenomicFeatures, S4Vectors, depmap, knitr,
        rmarkdown
biocViews: CellCulture, ColonCancerData, ExperimentHub, ExpressionData,
        GEO, Genome, Homo_sapiens_Data, MassSpectrometryData, Proteome,
        ReproducibleResearch, RNASeqData
git_url: https://git.bioconductor.org/packages/BioPlex
git_branch: devel
git_last_commit: fde35b2
git_last_commit_date: 2025-04-15
Repository: Bioconductor 3.22
Date/Publication: 2025-04-24
NeedsCompilation: no
Packaged: 2025-04-24 15:10:32 UTC; biocbuild
Author: Ludwig Geistlinger [aut, cre],
  Robert Gentleman [aut]
Maintainer: Ludwig Geistlinger <ludwig_geistlinger@hms.harvard.edu>
