# Generated by roxygen2: do not edit by hand

export(annotatePFAM)
export(bioplex2graph)
export(ccleProteome2SummarizedExperiment)
export(corum2graphlist)
export(corum2list)
export(getBioPlex)
export(getBioplexProteome)
export(getCorum)
export(getGSE122425)
export(getHEK293GenomeTrack)
export(hasSubunit)
export(mapSummarizedExperimentOntoGraph)
import(SummarizedExperiment)
importFrom(methods,as)
importFrom(utils,download.file)
importFrom(utils,read.csv)
importFrom(utils,read.delim)
importFrom(utils,relist)
importFrom(utils,unzip)
